/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Category, Node } from '@alfresco/js-api';
import { Observable, Subject } from 'rxjs';
import { AppConfigService, CardViewItem, NotificationService, TranslationService } from '@alfresco/adf-core';
import { ContentMetadataService } from '../../services/content-metadata.service';
import { CardViewGroup, PresetConfig, ContentMetadataCustomPanel, ContentMetadataPanel } from '../../interfaces/content-metadata.interfaces';
import { CardViewContentUpdateService } from '../../../common/services/card-view-content-update.service';
import { NodesApiService } from '../../../common/services/nodes-api.service';
import { TagsCreatorMode } from '../../../tag/tags-creator/tags-creator-mode';
import { TagService } from '../../../tag/services/tag.service';
import { CategoryService } from '../../../category/services/category.service';
import { CategoriesManagementMode } from '../../../category/categories-management/categories-management-mode';
import { ContentService } from '../../../common/services/content.service';
import * as i0 from "@angular/core";
declare enum DefaultPanels {
    PROPERTIES = "Properties",
    TAGS = "Tags",
    CATEGORIES = "Categories"
}
export declare class ContentMetadataComponent implements OnChanges, OnInit, OnDestroy {
    private contentMetadataService;
    private cardViewContentUpdateService;
    private nodesApiService;
    private translationService;
    private appConfig;
    private tagService;
    private categoryService;
    private contentService;
    private notificationService;
    protected onDestroy$: Subject<boolean>;
    /** (required) The node entity to fetch metadata about */
    node: Node;
    /** Toggles whether to display empty values in the card view */
    displayEmpty: boolean;
    /**
     * Toggles between expanded (ie, full information) and collapsed
     * (ie, reduced information) in the display
     */
    expanded: boolean;
    /** The multi parameter of the underlying material expansion panel, set to true to allow multi accordion to be expanded at the same time */
    multi: boolean;
    /** Name or configuration of the metadata preset, which defines aspects and their properties */
    preset: string | PresetConfig;
    /** Toggles whether the metadata properties should be shown */
    displayDefaultProperties: boolean;
    /** (optional) shows the given aspect in the expanded  card */
    displayAspect: string;
    /** Toggles whether or not to enable copy to clipboard action. */
    copyToClipboardAction: boolean;
    /** Toggles whether or not to enable chips for multivalued properties. */
    useChipsForMultiValueProperty: boolean;
    /** True if tags should be displayed, false otherwise */
    displayTags: boolean;
    /** True if categories should be displayed, false otherwise */
    displayCategories: boolean;
    /** List of custom metadata panels to be displayed with registered custom components */
    customPanels: ContentMetadataCustomPanel[];
    /**
     * (optional) This flag sets the metadata in read-only mode,
     * preventing changes.
     */
    readOnly: boolean;
    private _assignedTags;
    private assignedTagsEntries;
    private _tagsCreatorMode;
    private _tags;
    private targetProperty;
    private classifiableChangedSubject;
    private _saving;
    DefaultPanels: typeof DefaultPanels;
    multiValueSeparator: string;
    basicProperties$: Observable<CardViewItem[]>;
    groupedProperties$: Observable<CardViewGroup[]>;
    changedProperties: {};
    hasMetadataChanged: boolean;
    assignedCategories: Category[];
    categories: Category[];
    categoriesManagementMode: CategoriesManagementMode;
    classifiableChanged: Observable<void>;
    editing: boolean;
    editedPanelTitle: string;
    currentPanel: ContentMetadataPanel;
    constructor(contentMetadataService: ContentMetadataService, cardViewContentUpdateService: CardViewContentUpdateService, nodesApiService: NodesApiService, translationService: TranslationService, appConfig: AppConfigService, tagService: TagService, categoryService: CategoryService, contentService: ContentService, notificationService: NotificationService);
    ngOnInit(): void;
    private verifyAllowableOperations;
    get assignedTags(): string[];
    get tags(): string[];
    get tagsCreatorMode(): TagsCreatorMode;
    get saving(): boolean;
    isPanelEditing(panelTitle: string): boolean;
    protected handleUpdateError(error: Error): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    updateChanges(updatedNodeChanges: any): void;
    saveChanges(event?: MouseEvent): void;
    /**
     * Register all tags which should be assigned to node. Please note that they are just in "register" state and are not yet saved
     * until button for saving data is clicked. Calling that function causes that save button is enabled.
     *
     * @param tags array of tags to register, they are not saved yet until we click save button.
     */
    storeTagsToAssign(tags: string[]): void;
    /**
     * Store all categories that node should be assigned to. Please note that they are just in "stored" state and are not yet saved
     * until button for saving data is clicked. Calling that function causes that save button is enabled.
     *
     * @param categoriesToAssign array of categories to store.
     */
    storeCategoriesToAssign(categoriesToAssign: Category[]): void;
    revertChanges(): void;
    get showEmptyTagMessage(): boolean;
    get showEmptyCategoryMessage(): boolean;
    toggleGroupEditing(panelTitle: string, event?: MouseEvent): void;
    cancelGroupEditing(panelTitle: string, event?: MouseEvent): void;
    expandPanel(panelTitle: string): void;
    closePanel(panelTitle: string): void;
    resetEditing(): void;
    showGroup(group: CardViewGroup): boolean;
    keyDown(event: KeyboardEvent): void;
    private updateNode;
    private hasContentTypeChanged;
    private updateUndefinedNodeProperties;
    private loadProperties;
    private getProperties;
    private isEmpty;
    private loadCategoriesForNode;
    private saveCategories;
    private loadTagsForNode;
    private saveTags;
    static ɵfac: i0.ɵɵFactoryDeclaration<ContentMetadataComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ContentMetadataComponent, "adf-content-metadata", never, { "node": "node"; "displayEmpty": "displayEmpty"; "expanded": "expanded"; "multi": "multi"; "preset": "preset"; "displayDefaultProperties": "displayDefaultProperties"; "displayAspect": "displayAspect"; "copyToClipboardAction": "copyToClipboardAction"; "useChipsForMultiValueProperty": "useChipsForMultiValueProperty"; "displayTags": "displayTags"; "displayCategories": "displayCategories"; "customPanels": "customPanels"; "readOnly": "readOnly"; }, {}, never, never, false>;
}
export {};
