import { Subject, Observable, ReplaySubject } from 'rxjs';
import { AlfrescoApiService, AppConfigService } from '@alfresco/adf-core';
import { SearchRequest, RequestFacetFields, RequestSortDefinitionInner, ResultSetPaging, RequestHighlight, RequestScope, SearchApi } from '@alfresco/js-api';
import { SearchCategory } from '../models/search-category.interface';
import { FilterQuery } from '../models/filter-query.interface';
import { SearchRange } from '../models/search-range.interface';
import { SearchConfiguration } from '../models/search-configuration.interface';
import { FacetQuery } from '../models/facet-query.interface';
import { SearchSortingDefinition } from '../models/search-sorting-definition.interface';
import { FacetField } from '../models/facet-field.interface';
import { FacetFieldBucket } from '../models/facet-field-bucket.interface';
import { SearchForm } from '../models/search-form.interface';
import * as i0 from "@angular/core";
export declare abstract class BaseQueryBuilderService {
    protected appConfig: AppConfigService;
    protected alfrescoApiService: AlfrescoApiService;
    private _searchApi;
    get searchApi(): SearchApi;
    configUpdated: Subject<SearchConfiguration>;
    updated: Subject<SearchRequest>;
    executed: Subject<ResultSetPaging>;
    error: Subject<unknown>;
    searchForms: ReplaySubject<SearchForm[]>;
    categories: SearchCategory[];
    queryFragments: {
        [id: string]: string;
    };
    filterQueries: FilterQuery[];
    paging: {
        maxItems?: number;
        skipCount?: number;
    };
    sorting: SearchSortingDefinition[];
    sortingOptions: SearchSortingDefinition[];
    private scope;
    private selectedConfiguration;
    private _userQuery;
    protected userFacetBuckets: {
        [key: string]: FacetFieldBucket[];
    };
    get userQuery(): string;
    set userQuery(value: string);
    config: SearchConfiguration;
    ranges: {
        [id: string]: SearchRange;
    };
    protected constructor(appConfig: AppConfigService, alfrescoApiService: AlfrescoApiService);
    abstract loadConfiguration(): SearchConfiguration | SearchConfiguration[];
    abstract isFilterServiceActive(): boolean;
    resetToDefaults(): void;
    getDefaultConfiguration(): SearchConfiguration | undefined;
    updateSelectedConfiguration(index: number): void;
    private resetSearchOptions;
    getSearchFormDetails(): SearchForm[];
    private setUpSearchConfiguration;
    /**
     * Adds a facet bucket to a field.
     *
     * @param field The target field
     * @param bucket Bucket to add
     */
    addUserFacetBucket(field: string, bucket: FacetFieldBucket): void;
    /**
     * Gets the buckets currently added to a field
     *
     * @param field The target fields
     * @returns Bucket array
     */
    getUserFacetBuckets(field: string): FacetFieldBucket[];
    /**
     * Removes an existing bucket from a field.
     *
     * @param field The target field
     * @param bucket Bucket to remove
     */
    removeUserFacetBucket(field: string, bucket: FacetFieldBucket): void;
    /**
     * Adds a filter query to the current query.
     *
     * @param query Query string to add
     */
    addFilterQuery(query: string): void;
    /**
     * Removes an existing filter query.
     *
     * @param query The query to remove
     */
    removeFilterQuery(query: string): void;
    /**
     * Gets a facet query by label.
     *
     * @param label Label of the query
     * @returns Facet query data
     */
    getFacetQuery(label: string): FacetQuery;
    /**
     * Gets a facet field by label.
     *
     * @param label Label of the facet field
     * @returns Facet field data
     */
    getFacetField(label: string): FacetField;
    setScope(scope: RequestScope): void;
    getScope(): RequestScope;
    /**
     * Builds the current query and triggers the `updated` event.
     *
     * @param queryBody query settings
     */
    update(queryBody?: SearchRequest): void;
    /**
     * Builds and executes the current query.
     *
     * @param queryBody query settings
     */
    execute(queryBody?: SearchRequest): Promise<void>;
    search(queryBody: SearchRequest): Observable<ResultSetPaging>;
    /**
     * Builds the current query.
     *
     * @returns The finished query
     */
    buildQuery(): SearchRequest;
    /**
     * Gets the primary sorting definition.
     *
     * @returns The primary sorting definition
     */
    getPrimarySorting(): SearchSortingDefinition;
    /**
     * Gets all pre-configured sorting options that users can choose from.
     *
     * @returns Pre-configured sorting options
     */
    getSortingOptions(): SearchSortingDefinition[];
    /**
     * Gets the query group.
     *
     * @param query Target query
     * @returns Query group
     */
    getQueryGroup(query: FacetQuery): string;
    /**
     * Checks if FacetQueries has been defined
     *
     * @returns True if defined, false otherwise
     */
    get hasFacetQueries(): boolean;
    /**
     * Checks if FacetIntervals has been defined
     *
     * @returns True if defined, false otherwise
     */
    get hasFacetIntervals(): boolean;
    get hasFacetHighlight(): boolean;
    protected get sort(): RequestSortDefinitionInner[];
    protected get facetQueries(): FacetQuery[];
    protected get facetIntervals(): any;
    protected get highlight(): RequestHighlight;
    protected getFinalQuery(): string;
    protected get facetFields(): RequestFacetFields;
    /**
     * Encloses a label name with double quotes if it contains whitespace characters.
     *
     * @param configLabel Original label text
     * @returns Label, possibly with quotes if it contains spaces
     */
    getSupportedLabel(configLabel: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseQueryBuilderService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BaseQueryBuilderService>;
}
