/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { TagEntry } from '@alfresco/js-api';
import { EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { FormControl } from '@angular/forms';
import { NotificationService } from '@alfresco/adf-core';
import { TagsCreatorMode } from './tags-creator-mode';
import { TagService } from '../services/tag.service';
import * as i0 from "@angular/core";
interface TagNameControlErrors {
    duplicatedExistingTag?: boolean;
    duplicatedAddedTag?: boolean;
    emptyTag?: boolean;
    required?: boolean;
    specialCharacters?: boolean;
}
/**
 * Allows to create multiple tags. That component contains input and two lists. Top list is all created tags, bottom list is searched tags based on input's value.
 */
export declare class TagsCreatorComponent implements OnInit, OnDestroy {
    private tagService;
    private notificationService;
    /**
     * Mode for component.
     * In Create mode we can't select existing tags, we can only create them.
     * In Create and Assign mode we can both - create tags and select existing tags.
     */
    mode: TagsCreatorMode;
    /**
     * False if tags can be removed from top list, true otherwise.
     */
    disabledTagsRemoving: boolean;
    /**
     * Default top list.
     *
     * @param tags tags which should be displayed as default tags for top list.
     */
    set tags(tags: string[]);
    get tags(): string[];
    /**
     * Decides if input for tags creation/searching should be visible. When input is hidden then panel of existing tags is hidden as well.
     *
     * @param tagNameControlVisible true if input should be visible, false otherwise.
     */
    set tagNameControlVisible(tagNameControlVisible: boolean);
    get tagNameControlVisible(): boolean;
    /**
     * Emitted when bottom list is showing or hiding.
     */
    existingTagsPanelVisibilityChange: EventEmitter<boolean>;
    /**
     * Emitted when tags in top list are changed.
     */
    tagsChange: EventEmitter<string[]>;
    readonly nameErrorMessagesByErrors: Map<keyof TagNameControlErrors, string>;
    private readonly existingTagsListLimit;
    private exactTagSet$;
    private _tags;
    private _tagNameControl;
    private _tagNameControlVisible;
    private _existingTags;
    private _initialExistingTags;
    private onDestroy$;
    private _tagNameErrorMessageKey;
    private _spinnerVisible;
    private _typing;
    private _tagsListScrollbarVisible;
    private cancelExistingTagsLoading$;
    private existingExactTag;
    private _existingTagsPanelVisible;
    private tagsListElement;
    private tagNameInputElement;
    constructor(tagService: TagService, notificationService: NotificationService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    get hostClass(): boolean;
    get tagNameControl(): FormControl<string>;
    get showEmptyTagMessage(): boolean;
    get existingTags(): TagEntry[];
    get tagNameErrorMessageKey(): string;
    get spinnerVisible(): boolean;
    get typing(): boolean;
    get tagsListScrollbarVisible(): boolean;
    get existingTagsPanelVisible(): boolean;
    /**
     * Add tags to top list using value which is set in input. Adding tag is not allowed when value in input is invalid
     * or if user is still typing what means that validation for input is not called yet.
     */
    addTag(): void;
    /**
     * Remove tag from top list. In case that tag was part of search result then that tag is moved to bottom list
     * (list of existing tags) after removing so user can reselect it again later.
     *
     * @param tag tag's name which should be removed from top list.
     */
    removeTag(tag: string): void;
    /**
     * Called when user selects any tag from list of existing tags. It moves tag from existing tags list to top list.
     *
     * @param selectedTag changes
     */
    addExistingTagToTagsToAssign(selectedTag: TagEntry): void;
    /**
     * Checks if component is in Create mode.
     *
     * @returns `true` if `Create` mode, `false` otherwise.
     */
    isOnlyCreateMode(): boolean;
    private onTagNameControlValueChange;
    private loadTags;
    private removeExactTagFromSearchedResult;
    private validateIfNotExistingTag;
    private validateIfNotAlreadyAdded;
    private compareTags;
    private validateEmptyTag;
    private validateSpecialCharacters;
    private setTagNameControlErrorMessageKey;
    private checkScrollbarVisibility;
    private removeTagFromArray;
    private updateExistingTagsListOnRemoveFromTagsToConfirm;
    private sortExistingTags;
    private excludeAlreadyAddedTags;
    private clearTagNameInput;
    static ɵfac: i0.ɵɵFactoryDeclaration<TagsCreatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TagsCreatorComponent, "adf-tags-creator", never, { "mode": "mode"; "disabledTagsRemoving": "disabledTagsRemoving"; "tags": "tags"; "tagNameControlVisible": "tagNameControlVisible"; }, { "existingTagsPanelVisibilityChange": "existingTagsPanelVisibilityChange"; "tagsChange": "tagsChange"; }, never, never, false>;
}
export {};
